﻿using ProjectByldozer.CollectionGenericObjects;
using ProjectByldozer.Drawnings;


namespace ProjectByldozer;
/// <summary>
/// Форма работы с компанией и ее коллекцией
/// </summary>

public partial class FormCarCollection : Form
{
    /// <summary>
	/// Компания
	/// </summary>
	private AbstractCompany? _company = null;

    /// <summary>
	/// Конструктор
	/// </summary>
    public FormCarCollection()
    {
        InitializeComponent();
    }

    private void ComboBoxSelectionCompany_SelectedIndexChanged(object sender, EventArgs e)
    {
        switch (comboBoxSelectionCompany.Text)
        {
            case "Хранилище":
                _company = new TrackedCarGarage(pictureBox.Width, pictureBox.Height, new MassiveGenericObjects<DrawningTrackedCar>());
                break;
        }
    }
    /// <summary>
    /// Добавление обычной машины
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    private void ButtonAddByldozer_Click(object sender, EventArgs e) => CreateObject(nameof(DrawningByldozer));


    /// /// Добавление полного экскаватора
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    private void ButtonAddTrackedCar_Click(object sender, EventArgs e) => CreateObject(nameof(DrawningTrackedCar));

    private void CreateObject(string type)
    {
        if (_company == null)
        {
            return;
        }

        Random random = new();
        DrawningTrackedCar drawningTrackedCar;
        switch (type)
        {
            case nameof(DrawningTrackedCar):
                drawningTrackedCar = new DrawningTrackedCar(random.Next(100, 300), random.Next(1000, 3000), GetColor(random));
                break;
            case nameof(DrawningByldozer):
                // TODO вызов диалогового окна для выбора цвета
                drawningTrackedCar = new DrawningByldozer(random.Next(100, 300), random.Next(1000, 3000),
                    GetColor(random), GetColor(random),
                    Convert.ToBoolean(random.Next(0, 2)), Convert.ToBoolean(random.Next(0, 2)), Convert.ToBoolean(random.Next(0, 2)));
                break;
            default:
                return;
        }

        if (_company + drawningTrackedCar != -1)
        {
            MessageBox.Show("Объект добавлен");
            pictureBox.Image = _company.Show();
        }
        else
        {
            MessageBox.Show("Не удалось добавить объект");
        }
    }

    private static Color GetColor(Random random)
    {
        Color color = Color.FromArgb(random.Next(0, 256), random.Next(0, 256), random.Next(0, 256));
        ColorDialog dialog = new();
        if (dialog.ShowDialog() == DialogResult.OK)
        {
            color = dialog.Color;
        }

        return color;
    }

    private void ButtonDelCar_Click(object sender, EventArgs e)
    {
        if (string.IsNullOrEmpty(maskedTextBox.Text) || _company == null)
        {
            return;
        }

        if (MessageBox.Show("Удалить объект?", "Удаление", MessageBoxButtons.YesNo, MessageBoxIcon.Question) != DialogResult.Yes)
        {
            return;
        }

        int pos = Convert.ToInt32(maskedTextBox.Text);
        if (_company - pos != null)
        {
            MessageBox.Show("Объект удален");
            pictureBox.Image = _company.Show();
        }
        else
        {
            MessageBox.Show("Не удалось удалить объект");
        }

    }

    private void ButtonGoToCheck_Click(object sender, EventArgs e)
    {
        if (_company == null)
        {
            return;
        }

        DrawningTrackedCar? trackedcar = null;
        int counter = 100;
        while (trackedcar == null)
        {
            trackedcar = _company.GetRandomObject();
            counter--;
            if (counter <= 0)
            {
                break;
            }
        }

        if (trackedcar == null)
        {
            return;
        }
        FormByldozer form = new()
        {
            SetTrackedCar = trackedcar
        };
        form.ShowDialog();

    }

    private void ButtonRefresh_Click(object sender, EventArgs e)
    {
            if (_company == null)
            {
                return;
            }

            pictureBox.Image = _company.Show();
    }
    
}
